@@ -30,11 +30,15 @@ def random_string(length, choices=string.ascii_letters):
     return text
 
 def char_force_to_int(value):
+    if value is None:
+        return None
     if isinstance(value, int):
         return value
     return ord(value)
 
 def force_bytes(value, encoding="utf-8"):
+    if value is None:
+        return None
     if isinstance(value, text_type):
         encoding = encoding or "utf-8"
         return value.encode(encoding)
@@ -42,6 +46,8 @@ def force_bytes(value, encoding="utf-8"):
         return value
 
 def force_text(value, encoding=None):
+    if value is None:
+        return None
     if isinstance(value, text_type):
         return value
     if not encoding:
@@ -58,18 +64,45 @@ def force_text(value, encoding=None):
     raise UnicodeDecodeError()
 
 def force_int(value):
+    if value is None:
+        return None
     if isinstance(value, int):
         return value
-    elif isinstance(value, str):
-        return int(value)
-    elif isinstance(value, bytes):
-        return int(value.decode())
-    elif isinstance(value, float):
-        return int(value)
-    elif isinstance(value, Decimal):
+    if isinstance(value, float):
         return int(value)
+    if isinstance(value, Decimal):
+        return int(value.to_integral_value())
+    if isinstance(value, bytes):
+        value = value.decode("utf-8")
+    value = str(value)
+    return int(value)
+
+def force_float(value):
+    if value is None:
+        return None
+    if isinstance(value, float):
+        return value
+    if isinstance(value, int):
+        return float(value)
+    if isinstance(value, Decimal):
+        return float(value)
+    if isinstance(value, bytes):
+        value = value.decode("utf-8")
+    value = str(value)
+    return float(value)
+
+def force_numberic(value):
+    if value is None:
+        return None
+    if isinstance(value, (int, float, Decimal)):
+        return value
+    if isinstance(value, bytes):
+        value = value.decode("utf-8")
+    value = str(value)
+    if "." in value:
+        return float(value)
     else:
-        raise RuntimeError("force_int failed: value={}".format(value))
+        return int(value)
 
 def wholestrip(text):
     """Remove all white spaces in text. White spaces are ' \t\n\r\x0b\x0c\u3000'.
